@@ -19,6 +19,19 @@ package types;
 import org.ovirt.api.metamodel.annotations.Link;
 import org.ovirt.api.metamodel.annotations.Type;
 
+/**
+ * Deprecated type to specify _cloud-init_ configuration.
+ *
+ * This type has been deprecated and replaced by alternative attributes inside the
+ * <<types/initialization, Initialization>> type. See the
+ * <<types/initialization/attributes/cloud_init, cloud_init>> attribute documentation for details.
+ *
+ * @author Juan Hernandez <juan.hernandez@redhat.com>
+ * @author Byron Gravenorst <bgraveno@redhat.com>
+ * @date 25 Jul 2017
+ * @status updated_by_docs
+ */
+@Deprecated
 @Type
 public interface CloudInit {
     Host host();
