@@ -17,6 +17,7 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -34,7 +35,7 @@ public interface HostNumaNodesService {
      * @date 15 Arp 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out NumaNode[] nodes();
 
         /**
