@@ -17,11 +17,15 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.Cdrom;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 /**
  * Manages a CDROM device of a virtual machine.
  *
@@ -65,7 +69,7 @@ public interface VmCdromService {
      * @date 14 Sep 2016
      * @status added
      */
-    interface Get {
+    interface Get extends Follow {
         /**
          * The information about the CDROM device.
          *
@@ -146,6 +150,10 @@ public interface VmCdromService {
      * @status added
      */
     interface Update {
+        @InputDetail
+        default void inputDetail() {
+            optional(cdrom().file().id());
+        }
         /**
          * The information about the CDROM device.
          *
