@@ -17,11 +17,17 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.VirtualNumaNode;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.COLLECTION;
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 @Service
 @Area("SLA")
 public interface VmNumaNodesService {
@@ -57,6 +63,13 @@ public interface VmNumaNodesService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(node().index());
+            mandatory(node().memory());
+            mandatory(node().cpu().cores()[COLLECTION].index());
+            optional(node().numaNodePins()[COLLECTION].index());
+        }
         @In @Out VirtualNumaNode node();
     }
 
@@ -69,7 +82,7 @@ public interface VmNumaNodesService {
      * @date 14 Sep 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out VirtualNumaNode[] nodes();
 
         /**
