@@ -232,6 +232,20 @@ public interface DiskService extends MeasurableService {
      * Retrieves the description of the disk.
      */
     public interface GetRequest extends Request<GetRequest, GetResponse> {
+        /**
+         * Indicates if all of the attributes of the disk should be included in the response.
+         * 
+         * By default the following disk attributes are excluded:
+         * 
+         * - `vms`
+         * 
+         * For example, to retrieve the complete representation of disk '123':
+         * 
+         * ....
+         * GET /ovirt-engine/api/disks/123?all_content=true
+         * ....
+         */
+        GetRequest allContent(Boolean allContent);
         /**
          * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
          * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
@@ -406,6 +420,39 @@ public interface DiskService extends MeasurableService {
      */
     MoveRequest move();
     
+    /**
+     * Reduces the size of the disk image.
+     * 
+     * Invokes _reduce_ on the logical volume (i.e. this is only applicable for block storage domains).
+     * This is applicable for floating disks and disks attached to non-running virtual machines.
+     * There is no need to specify the size as the optimal size is calculated automatically.
+     */
+    public interface ReduceRequest extends Request<ReduceRequest, ReduceResponse> {
+        /**
+         * Indicates if the remove should be performed asynchronously.
+         */
+        ReduceRequest async(Boolean async);
+    }
+    
+    /**
+     * Reduces the size of the disk image.
+     * 
+     * Invokes _reduce_ on the logical volume (i.e. this is only applicable for block storage domains).
+     * This is applicable for floating disks and disks attached to non-running virtual machines.
+     * There is no need to specify the size as the optimal size is calculated automatically.
+     */
+    public interface ReduceResponse extends Response {
+    }
+    
+    /**
+     * Reduces the size of the disk image.
+     * 
+     * Invokes _reduce_ on the logical volume (i.e. this is only applicable for block storage domains).
+     * This is applicable for floating disks and disks attached to non-running virtual machines.
+     * There is no need to specify the size as the optimal size is calculated automatically.
+     */
+    ReduceRequest reduce();
+    
     /**
      * Refreshes a direct LUN disk with up-to-date information from the storage.
      * 
