@@ -17,6 +17,7 @@ package org.ovirt.engine.sdk4.internal.containers;
 
 import java.lang.String;
 import java.math.BigInteger;
+import org.ovirt.engine.sdk4.types.GlusterVolume;
 import org.ovirt.engine.sdk4.types.Host;
 import org.ovirt.engine.sdk4.types.NfsVersion;
 import org.ovirt.engine.sdk4.types.StorageConnection;
@@ -36,6 +37,7 @@ public class StorageConnectionContainer extends IdentifiedContainer implements S
     private StorageType type;
     private String username;
     private String vfsType;
+    private GlusterVolume glusterVolume;
     private Host host;
     
     public String address() {
@@ -242,6 +244,18 @@ public class StorageConnectionContainer extends IdentifiedContainer implements S
         return vfsType != null;
     }
     
+    public GlusterVolume glusterVolume() {
+        return glusterVolume;
+    }
+    
+    public void glusterVolume(GlusterVolume newGlusterVolume) {
+        glusterVolume = newGlusterVolume;
+    }
+    
+    public boolean glusterVolumePresent() {
+        return glusterVolume != null;
+    }
+    
     public Host host() {
         return host;
     }
