@@ -118,6 +118,111 @@ public class StorageServerConnectionServiceImpl extends ServiceImpl implements S
         return new GetRequestImpl();
     }
     
+    private class UpdateGlusterfsRequestImpl extends BaseRequest<UpdateGlusterfsRequest, UpdateGlusterfsResponse> implements UpdateGlusterfsRequest {
+        private Boolean async;
+        public UpdateGlusterfsRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        private StorageConnection connection;
+        public UpdateGlusterfsRequest connection(StorageConnection connection) {
+            this.connection = connection;
+            return this;
+        }
+        
+        public UpdateGlusterfsRequest connection(StorageConnectionBuilder connection) {
+            this.connection = connection.build();
+            return this;
+        }
+        
+        private Boolean force;
+        public UpdateGlusterfsRequest force(Boolean force) {
+            this.force = force;
+            return this;
+        }
+        
+        public UpdateGlusterfsResponse send() {
+            HttpPut request = null;
+            try {
+                URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (async != null) {
+                    uriBuilder.addParameter("async", XmlWriter.renderBoolean(async));
+                }
+                if (force != null) {
+                    uriBuilder.addParameter("force", XmlWriter.renderBoolean(force));
+                }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
+                request = new HttpPut(uriBuilder.build());
+            }
+            catch (URISyntaxException ex) {
+                throw new Error("Failed to build URL", ex);
+            }
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                XmlStorageConnectionWriter.writeOne(connection, xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to parse response", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            if (
+              response.getStatusLine().getStatusCode() == 200
+            ) {
+                try (
+                  XmlReader reader = new XmlReader(response.getEntity().getContent())
+                ) {
+                    UpdateGlusterfsResponseImpl actionResponse = new UpdateGlusterfsResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
+                }
+                catch (IOException ex) {
+                    throw new Error("Failed to read response", ex);
+                }
+                finally {
+                    EntityUtils.consumeQuietly(response.getEntity());
+                }
+            }
+            else {
+                checkFault(response);
+                return new UpdateGlusterfsResponseImpl();
+            }
+        }
+        
+    }
+    
+    private class UpdateGlusterfsResponseImpl implements UpdateGlusterfsResponse {
+        private StorageConnection connection;
+        
+        public void connection(StorageConnection connection) {
+            this.connection = connection;
+        }
+        
+        public StorageConnection connection() {
+            return connection;
+        }
+        
+    }
+    
+    public UpdateGlusterfsRequest updateGlusterfs() {
+        return new UpdateGlusterfsRequestImpl();
+    }
+    
     private class UpdateIscsiRequestImpl extends BaseRequest<UpdateIscsiRequest, UpdateIscsiResponse> implements UpdateIscsiRequest {
         private Boolean async;
         public UpdateIscsiRequest async(Boolean async) {
