@@ -99,7 +99,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlStorageConnectionReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class AddResponseImpl implements AddResponse {
         private StorageConnection connection;
         
-        public AddResponseImpl(StorageConnection connection) {
+        public void connection(StorageConnection connection) {
             this.connection = connection;
         }
         
@@ -133,6 +135,95 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
         return new AddRequestImpl();
     }
     
+    private class AddGlusterfsRequestImpl extends BaseRequest<AddGlusterfsRequest, AddGlusterfsResponse> implements AddGlusterfsRequest {
+        private StorageConnection connection;
+        public AddGlusterfsRequest connection(StorageConnection connection) {
+            this.connection = connection;
+            return this;
+        }
+        
+        public AddGlusterfsRequest connection(StorageConnectionBuilder connection) {
+            this.connection = connection.build();
+            return this;
+        }
+        
+        public AddGlusterfsResponse send() {
+            HttpPost request = null;
+            try {
+                URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
+                request = new HttpPost(uriBuilder.build());
+            }
+            catch (URISyntaxException ex) {
+                throw new Error("Failed to build URL", ex);
+            }
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                XmlStorageConnectionWriter.writeOne(connection, xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to parse response", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            if (
+              response.getStatusLine().getStatusCode() == 200
+              || response.getStatusLine().getStatusCode() == 201
+              || response.getStatusLine().getStatusCode() == 202
+            ) {
+                try (
+                  XmlReader reader = new XmlReader(response.getEntity().getContent())
+                ) {
+                    AddGlusterfsResponseImpl actionResponse = new AddGlusterfsResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
+                }
+                catch (IOException ex) {
+                    throw new Error("Failed to read response", ex);
+                }
+                finally {
+                    EntityUtils.consumeQuietly(response.getEntity());
+                }
+            }
+            else {
+                checkFault(response);
+                return new AddGlusterfsResponseImpl();
+            }
+        }
+        
+    }
+    
+    private class AddGlusterfsResponseImpl implements AddGlusterfsResponse {
+        private StorageConnection connection;
+        
+        public void connection(StorageConnection connection) {
+            this.connection = connection;
+        }
+        
+        public StorageConnection connection() {
+            return connection;
+        }
+        
+    }
+    
+    public AddGlusterfsRequest addGlusterfs() {
+        return new AddGlusterfsRequestImpl();
+    }
+    
     private class AddIscsiRequestImpl extends BaseRequest<AddIscsiRequest, AddIscsiResponse> implements AddIscsiRequest {
         private StorageConnection connection;
         public AddIscsiRequest connection(StorageConnection connection) {
@@ -186,7 +277,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddIscsiResponseImpl(XmlStorageConnectionReader.readOne(reader));
+                    AddIscsiResponseImpl actionResponse = new AddIscsiResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -197,7 +290,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddIscsiResponseImpl(null);
+                return new AddIscsiResponseImpl();
             }
         }
         
@@ -206,7 +299,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class AddIscsiResponseImpl implements AddIscsiResponse {
         private StorageConnection connection;
         
-        public AddIscsiResponseImpl(StorageConnection connection) {
+        public void connection(StorageConnection connection) {
             this.connection = connection;
         }
         
@@ -277,7 +370,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlStorageConnectionReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.connections(XmlStorageConnectionReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -288,7 +383,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -297,7 +392,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class ListResponseImpl implements ListResponse {
         private List<StorageConnection> connections;
         
-        public ListResponseImpl(List<StorageConnection> connections) {
+        public void connections(List<StorageConnection> connections) {
             this.connections = connections;
         }
         
@@ -364,7 +459,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddLocalResponseImpl(XmlStorageConnectionReader.readOne(reader));
+                    AddLocalResponseImpl actionResponse = new AddLocalResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -375,7 +472,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddLocalResponseImpl(null);
+                return new AddLocalResponseImpl();
             }
         }
         
@@ -384,7 +481,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class AddLocalResponseImpl implements AddLocalResponse {
         private StorageConnection connection;
         
-        public AddLocalResponseImpl(StorageConnection connection) {
+        public void connection(StorageConnection connection) {
             this.connection = connection;
         }
         
@@ -451,7 +548,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddNfsResponseImpl(XmlStorageConnectionReader.readOne(reader));
+                    AddNfsResponseImpl actionResponse = new AddNfsResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -462,7 +561,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddNfsResponseImpl(null);
+                return new AddNfsResponseImpl();
             }
         }
         
@@ -471,7 +570,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class AddNfsResponseImpl implements AddNfsResponse {
         private StorageConnection connection;
         
-        public AddNfsResponseImpl(StorageConnection connection) {
+        public void connection(StorageConnection connection) {
             this.connection = connection;
         }
         
@@ -538,7 +637,9 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddVfsResponseImpl(XmlStorageConnectionReader.readOne(reader));
+                    AddVfsResponseImpl actionResponse = new AddVfsResponseImpl();
+                    actionResponse.connection(XmlStorageConnectionReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -549,7 +650,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddVfsResponseImpl(null);
+                return new AddVfsResponseImpl();
             }
         }
         
@@ -558,7 +659,7 @@ public class StorageServerConnectionsServiceImpl extends ServiceImpl implements
     private class AddVfsResponseImpl implements AddVfsResponse {
         private StorageConnection connection;
         
-        public AddVfsResponseImpl(StorageConnection connection) {
+        public void connection(StorageConnection connection) {
             this.connection = connection;
         }
         
