@@ -99,7 +99,9 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlGraphicsConsoleReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.console(XmlGraphicsConsoleReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
     private class AddResponseImpl implements AddResponse {
         private GraphicsConsole console;
         
-        public AddResponseImpl(GraphicsConsole console) {
+        public void console(GraphicsConsole console) {
             this.console = console;
         }
         
@@ -190,7 +192,9 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlGraphicsConsoleReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.consoles(XmlGraphicsConsoleReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +205,7 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +214,7 @@ public class TemplateGraphicsConsolesServiceImpl extends ServiceImpl implements
     private class ListResponseImpl implements ListResponse {
         private List<GraphicsConsole> consoles;
         
-        public ListResponseImpl(List<GraphicsConsole> consoles) {
+        public void consoles(List<GraphicsConsole> consoles) {
             this.consoles = consoles;
         }
         
