@@ -77,7 +77,9 @@ public class UnmanagedNetworkServiceImpl extends ServiceImpl implements Unmanage
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlUnmanagedNetworkReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.network(XmlUnmanagedNetworkReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -88,7 +90,7 @@ public class UnmanagedNetworkServiceImpl extends ServiceImpl implements Unmanage
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -97,7 +99,7 @@ public class UnmanagedNetworkServiceImpl extends ServiceImpl implements Unmanage
     private class GetResponseImpl implements GetResponse {
         private UnmanagedNetwork network;
         
-        public GetResponseImpl(UnmanagedNetwork network) {
+        public void network(UnmanagedNetwork network) {
             this.network = network;
         }
         
