@@ -97,6 +97,9 @@ public class XmlHostReader {
                 case "external_host_provider":
                 object.externalHostProvider(XmlExternalHostProviderReader.readOne(reader));
                 break;
+                case "external_network_provider_configurations":
+                object.externalNetworkProviderConfigurations(XmlExternalNetworkProviderConfigurationReader.readMany(reader));
+                break;
                 case "external_status":
                 object.externalStatus(XmlExternalStatusReader.readOne(reader));
                 break;
@@ -136,8 +139,11 @@ public class XmlHostReader {
                 case "network_attachments":
                 object.networkAttachments(XmlNetworkAttachmentReader.readMany(reader));
                 break;
+                case "network_operation_in_progress":
+                object.networkOperationInProgress(reader.readBoolean());
+                break;
                 case "nics":
-                object.nics(XmlNicReader.readMany(reader));
+                object.nics(XmlHostNicReader.readMany(reader));
                 break;
                 case "host_numa_nodes":
                 object.numaNodes(XmlNumaNodeReader.readMany(reader));
@@ -304,6 +310,11 @@ public class XmlHostReader {
                 list.href(href);
                 object.devices(list);
                 break;
+                case "externalnetworkproviderconfigurations":
+                list = new ArrayListWithHref(object.externalNetworkProviderConfigurations());
+                list.href(href);
+                object.externalNetworkProviderConfigurations(list);
+                break;
                 case "hooks":
                 list = new ArrayListWithHref(object.hooks());
                 list.href(href);
