@@ -108,6 +108,9 @@ public class XmlVmBaseWriter {
         if (object.migrationDowntimePresent()) {
             writer.writeInteger("migration_downtime", object.migrationDowntime());
         }
+        if (object.multiQueuesEnabledPresent()) {
+            writer.writeBoolean("multi_queues_enabled", object.multiQueuesEnabled());
+        }
         if (object.namePresent()) {
             writer.writeElement("name", object.name());
         }
