@@ -48,6 +48,11 @@ public interface DiskAttachmentService extends Service {
      * ----
      */
     public interface GetRequest extends Request<GetRequest, GetResponse> {
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        GetRequest follow(String follow);
     }
     
     /**
